@@ -11,7 +11,7 @@ import traceback
 from string import Template
 from os.path import expanduser
 
-version = '0.3.2'
+version = '0.3.4'
 
 logger = logging.getLogger("ppagent")
 config_home = expanduser("~/.ppagent/")
@@ -41,7 +41,7 @@ class WorkerNotFound(Exception):
 
 
 def easy_exit(code=0):
-    """ A helper to prevent the window from closing rapidly on windows """
+    """ A helper to prevent the window from closing rapidly on Windows """
     if sys.platform == "win32":
         raw_input("Press any key to continue...")
     exit(code)
@@ -77,7 +77,7 @@ class Miner(object):
     but in the future other miners could be interfaced with. """
 
     def __init__(self):
-        """ Recieves a dictionary of arguments defined in the miner declaration
+        """ Receives a dictionary of arguments defined in the miner declaration
         """
         raise NotImplementedError
 
@@ -119,7 +119,7 @@ class CGMiner(Miner):
         now = int(time.time())
         for coll in self.collectors.values():
             interval = coll['interval']
-            coll['next_run'] = ((now // interval) * interval)
+            coll['next_run'] = ((now // interval) * interval) + interval
 
     @property
     def worker(self):
@@ -136,19 +136,19 @@ class CGMiner(Miner):
             self.queue.append([self.worker, 'thresholds', self.thresholds, now])
             self.sent_thresholds = True
 
+        mhs = []
         # if it's time to run, and we have status defined
         if ('status' in self.collectors or
-                'temp' in self.collectors or
-                'hashrate' in self.collectors):
-            ret = self.call_devs()
-            mhs, temps, details = ret
+            'temp' in self.collectors or
+            'hashrate' in self.collectors) and now >= self.collectors['status']['next_run']:
+            mhs, temps, details = self.call_devs()
 
         if 'status' in self.collectors and now >= self.collectors['status']['next_run']:
             conf = self.collectors['status']
             gpus = [{} for _ in temps]
             output = {"type": "cgminer", "gpus": gpus, "pool": self.pool_stat()}
             # if it failed to connect we should just skip collection
-            if ret is None:
+            if details is None:
                 return
             if conf['temperature']:
                 for i, temp in enumerate(temps):
@@ -224,10 +224,12 @@ class CGMiner(Miner):
         # difference since last run, as opposed to reporting cgminers avg
         # megahash or 5s megahash
         if self.last_devs and len(self.last_devs) == len(data['DEVS']):
-            mhs = [round(now['Total MH'] - last['Total MH'], 3)
+            diff = time.time() - self._last_dev
+            mhs = [round((now['Total MH'] - last['Total MH']) / diff, 3)
                    for now, last in zip(data['DEVS'], self.last_devs)]
         else:
-            mhs = [d.get('MHS 5s') for d in data['DEVS'] if 'MHS 5s' in d]
+            mhs = []
+        self._last_dev = time.time()
         self.last_devs = data['DEVS']
         return mhs, temps, details
 
@@ -272,20 +274,20 @@ class AgentSender(object):
 
         return True
 
-    def recieve(self):
+    def receive(self):
         if self.conn is None:
             return {}
 
         try:
             recv = self.conn.readline(4096)
         except socket.error as e:
-            logger.debug("Failed to recieve response, connection error", exc_info=True)
+            logger.debug("Failed to receive response, connection error", exc_info=True)
             self.reset_connection()
             return {}
 
         if len(recv) > 4000:
             raise Exception("Server returned too large of a string")
-        logger.debug("Recieved response from server {0}".format(recv.strip()))
+        logger.debug("Received response from server {0}".format(recv.strip()))
         if not recv:
             self.reset_connection()
             return {}
@@ -324,7 +326,7 @@ class AgentSender(object):
                     time.sleep(5)
                     continue
 
-                retval = self.recieve()
+                retval = self.receive()
                 if retval.get('error', True) is None:
                     logger.debug("Successfully authenticated {0}".format(username))
                     miner.authenticated = True
@@ -351,17 +353,17 @@ class AgentSender(object):
             farthest = 0
             for i, value in enumerate(miner.queue):
                 send = {'method': 'stats.submit', 'params': value}
-                logger.info("Transmiting new stats: {0}".format(send))
+                logger.info("Transmitting new stats: {0}".format(send))
                 if not self.send(send):
                     logger.warn("Unable to send to remote, probably down temporarily.")
                     time.sleep(5)
                     break
 
                 # try to get a response from the server. if we fail to
-                # recieve, just wait till next loop to send
-                ret = self.recieve()
+                # receive, just wait till next loop to send
+                ret = self.receive()
                 if ret is None or ret.get('error', True) is not None:
-                    logger.warn("Recieved failure result '{0}' from the server!"
+                    logger.warn("Received failure result '{0}' from the server!"
                                 .format(ret))
                     break
                 farthest = i + 1
